import multiprocessing as mp
import os
import pickle
from functools import partial
from pathlib import Path

import pandas as pd
import wfdb

import lifedataphysionetchallenge as lpc

DATA_RAW_PATH = lpc.get_project_root() / "data" / "raw"


def main():
    files = [i.with_suffix('') for i in DATA_RAW_PATH.rglob('*.hea')]

    with mp.Pool() as pool:
        meta_df = pd.concat(pool.map(metadf, files))

    with open(lpc.get_project_root() / "data-analysis" / "meta_df.pickle", 'wb') as f:
        pickle.dump(meta_df, f)


def metadf(filename):
    data = readwfdb(filename)

    com = data.comments

    com_dict = {sub.split(": ")[0].replace("'", ""): sub.split(
        ": ")[1].replace("'", "") for sub in str(com)[1:-1].split(", ")}

    # NOTE: Filename is used because data.recordname may contain errors
    # when read with the wfdb package

    return pd.DataFrame(com_dict, index=[filename])


def readwfdb(filename):
    return wfdb.rdrecord(str(filename))


if __name__ == "__main__":
    main()

    meta_df = pd.read_pickle(Path.cwd() / "data-analysis" / "meta_df.pickle")
    print(meta_df)
