import logging
import multiprocessing as mp
import os
import pickle
from functools import partial
from pathlib import Path

import pandas as pd
import wfdb

import lifedataphysionetchallenge as lpc

DATA_RAW_PATH = lpc.get_project_root() / "data" / "raw"


def main():
    files = [i.with_suffix('') for i in DATA_RAW_PATH.rglob('*.hea')]

    with mp.Pool() as pool:
        sample_df = pd.concat(pool.map(sampledf, files))

    with open(lpc.get_project_root() / "data-analysis" / "sample_df.pickle", 'wb') as f:
        pickle.dump(sample_df, f)


def sampledf(filename):
    data = readwfdb(filename)

    sr = data.fs
    nr_samp = data.sig_len
    st = nr_samp / sr

    return pd.DataFrame({"samplerate": sr, "nr_samples": nr_samp, "signalduration": st}, index=[filename])


def readwfdb(filename):
    return wfdb.rdrecord(str(filename))


if __name__ == "__main__":
    main()

    sample_df = pd.read_pickle(
        Path.cwd() / "data-analysis" / "sample_df.pickle")

    print(sample_df)
