import logging
import multiprocessing as mp
import os
import pickle
from functools import partial
from pathlib import Path

import pandas as pd
import wfdb

import lifedataphysionetchallenge as lpc

DATA_RAW_PATH = lpc.get_project_root() / "data" / "raw"


def main():
    files = [i.with_suffix('') for i in DATA_RAW_PATH.rglob('*.hea')]

    with mp.Pool() as pool:
        units_df = pd.concat(pool.map(unitsdf, files))

    with open(lpc.get_project_root() / "data-analysis" / "units_df.pickle", 'wb') as f:
        pickle.dump(units_df, f)


def unitsdf(filename):
    data, leads = readwfdb(filename)

    units = data.units

    return pd.DataFrame([units], columns=["unit_" + lead for lead in leads], index=[filename])


def readwfdb(filename):
    data = wfdb.rdrecord(str(filename))
    leads = data.sig_name

    return data, leads


if __name__ == "__main__":
    main()

    units_df = pd.read_pickle(Path.cwd() / "data-analysis" / "units_df.pickle")
    print(units_df)
