import logging
import multiprocessing as mp
import os
import pickle
from functools import partial
from pathlib import Path

import numpy as np
import pandas as pd
import wfdb
import yaml
from scipy.io import loadmat

import lifedataphysionetchallenge as lpc

DATA_RAW_PATH = lpc.get_project_root() / "data" / "raw"


def main():
    files = [i.with_suffix('') for i in DATA_RAW_PATH.rglob('*.hea')]
    with mp.Pool() as pool:
        value_df = pd.concat(pool.map(valuedf, files))

    with open(lpc.get_project_root() / "data-analysis" / "value_df.pickle", 'wb') as f:
        pickle.dump(value_df, f)


def valuedf(filename):
    data, leads = readwfdb(filename)

    low = np.array([i.min() for i in data])
    high = np.array([i.max() for i in data])
    mean = np.array([i.mean() for i in data])
    dif = high - low

    min_df = pd.DataFrame(
        [low], columns=["min_value_" + lead for lead in leads], index=[filename])
    max_df = pd.DataFrame(
        [high], columns=["max_value_" + lead for lead in leads], index=[filename])
    mean_df = pd.DataFrame(
        [mean], columns=["mean_value_" + lead for lead in leads], index=[filename])
    dif_df = pd.DataFrame(
        [dif], columns=["dif_value_" + lead for lead in leads], index=[filename])

    return pd.concat([min_df, max_df, mean_df, dif_df], axis=1)


def readwfdb(header_file):
    header = wfdb.rdheader(header_file)
    
    data = wfdb.rdsamp(str(header_file))

    recording = data[0].T

    # mat_file = header_file.with_suffix('.mat')
    # x = loadmat(mat_file)
    # recording = np.asarray(x['val'], dtype=np.float64)

    labels = header.sig_name

    return recording, labels


if __name__ == "__main__":
    main()

    value_df = pd.read_pickle(Path.cwd() / "data-analysis" / "value_df.pickle")
    print(value_df)
