#%%
from pathlib import Path
from sklearn.model_selection import GroupShuffleSplit
import shutil
import pandas as pd
import yaml
import csv
from sklearn.model_selection import train_test_split
import lifedataphysionetchallenge as lpc
import logging
import wfdb
from lifedataphysionetchallenge.util import snomed

#%%

DATA_RAW = lpc.get_project_root() / "data/raw"
DATA_TRAINTEST = lpc.get_project_root() / "data/train_test_split"
DATA_TRAINTEST.mkdir(parents=True, exist_ok=True)

#%%
with open(lpc.get_project_root()/"params.yaml") as par_file:
    params = yaml.safe_load(par_file)

RANDOM_STATE = params["RANDOM_STATE"]
TEST_SIZE = params["TRAIN_TEST_SPLIT"]["TEST_SIZE"]
UNUSEABLE_SIGNALS = params["TRAIN_TEST_SPLIT"]["UNUSEABLE_SIGNALS"]
ONLY_SNOMED_CLASSES = set(params["ONLY_SNOMED_CLASSES"])
SET_SIZE_FOR_DEBUGGING = params["SET_SIZE_FOR_DEBUGGING"]

#%%

# Load all headers
header_file_paths = list(DATA_RAW.glob("*.hea"))

#%%
# If we're restricting the classes we're training on, filter them out of the headers
# Check that the set of allowed classes isn't empty
if ONLY_SNOMED_CLASSES != set([]):
    logging.warning(f"Restricting classes to {ONLY_SNOMED_CLASSES}")
    allowed_headers = []
    for header_path in header_file_paths:
        # wfdb expects the path without a suffix, so replace it with empty string
        header = wfdb.rdheader(str(header_path.with_suffix("")))
        dx_ids = snomed.get_snomed_ids_from_header_comments(header.comments)
        # Check all of the header ids are in the set of allowed IDs
        # See https://stackoverflow.com/a/27116142
        if set(dx_ids) <= ONLY_SNOMED_CLASSES:
            # All of the dx_ids are in the set of allowed classes
            allowed_headers = allowed_headers + [header_path]
    
    # Only keep allowed headers
    header_file_paths = allowed_headers

# Grab each id "home/fabi/physionet2020/data/raw/HR11244.hea" => "HR11244"
record_ids = [header_path.stem for header_path in header_file_paths]
# Clean unuseable signals 
record_ids = [ele for ele in record_ids if ele not in UNUSEABLE_SIGNALS] 

train_ids, test_ids = train_test_split(record_ids, test_size=TEST_SIZE,
        random_state=RANDOM_STATE)

# If you want to quickly debug the pipeline without all data, set this param
if SET_SIZE_FOR_DEBUGGING != -1:
    train_ids = train_ids[:SET_SIZE_FOR_DEBUGGING]
    test_ids = test_ids[:SET_SIZE_FOR_DEBUGGING]

#%%
train_list_path = DATA_TRAINTEST / "train.csv"
test_list_path = DATA_TRAINTEST / "test.csv"

with train_list_path.open("w") as train_file:
    csvWriter = csv.writer(train_file)
    csvWriter.writerow(train_ids)

with test_list_path.open("w") as test_file:
    csvWriter = csv.writer(test_file)
    csvWriter.writerow(test_ids)

# %%
