import lifedataphysionetchallenge as lpc
import numpy as np
import pandas as pd
import yaml

MAPPING_CSV_PATH = lpc.get_project_root() / "data/SNOMED_DX_map.csv"

with open(lpc.get_project_root() / "params.yaml") as file:
    params = yaml.safe_load(file)

ONLY_SNOMED_CLASSES = params["ONLY_SNOMED_CLASSES"]

def get_mapping_table():
    """
    Returns a pandas dataframe containing all the mappings
    """

    return pd.read_csv(MAPPING_CSV_PATH)

def get_snomed_code_list():
    """
    Returns a numpy array of all SNOMED CT codes in the mapping table or the list of restricted IDs
    if ONLY_SNOMED_CLASSES param is set
    """
    if ONLY_SNOMED_CLASSES == []:
        # Return all values
        return MAPPING_DF["SNOMED CT Code"].values
    else:
        return np.array(ONLY_SNOMED_CLASSES)

def get_snomed_ids_from_header_comments(header_comments):
    """
    Looks for the Dx comment and parses the IDs from it

    header_comments: 
            ['Age: 36',
            'Sex: Female',
            'Dx: 427084000, 5737366, 7633736',
            'Rx: Unknown',
            'Hx: Unknown',
            'Sx: Unknown']
    return: [427084000, 5737366, 7633736]
    """

    for comment in header_comments:
        # Search for comment starting with "Dx:"
        if comment[:3] == "Dx:":
            dx_list = comment.split()[1:] # The first element is "Dx:",drop it
            # Convert the list of strings with a trailing comma into a list of IDs
            dx_ids = [int(label) for label in dx_list[0].split(",")]
            return dx_ids
    
    # If we iterated through the loop without returning, something is wrong
    raise ValueError(f"No Diagnosis Comment found {header_comments}")
            


MAPPING_DF = get_mapping_table()