#!/usr/bin/env python

import numpy as np
import os
import sys
import joblib
from get_12ECG_features import get_12ECG_features
import lifedataphysionetchallenge as lpc
import lifedataphysionetchallenge.preprocess
import lifedataphysionetchallenge.model_training
import lifedataphysionetchallenge.dower_transformation
from lifedataphysionetchallenge.util.ecg_multi_label_binarizer import get_binarizer


def run_12ECG_classifier(data, header_data, loaded_model):
    # Use your classifier here to obtain a label and score for each class.
    model = loaded_model[0]
    threshold = loaded_model[1]
    classes = loaded_model[2]

    # Preprocess
    segmented_data, header = lifedataphysionetchallenge.preprocess.preprocess(
        data, header_data)

    # Dower Transformation
    transformed_data, header = lifedataphysionetchallenge.dower_transformation.dowertransform(
        segmented_data, header)

    # Predicten
    # Since we're only predicting a single element, the input has to be wrapped in a list, and the output unwrapped from that list
    y_pred = model.predict(np.array([transformed_data]))[0]

    # Apply threshold to predictions
    current_label = y_pred > threshold

    return current_label, y_pred, classes


def load_12ECG_model(filename):
    # FIXME hardcoded the path to our pre-trained model until we can train the model on their machine
    #loaded_model = lifedataphysionetchallenge.model_training.load_model(
    #    filename)
    loaded_model = lifedataphysionetchallenge.model_training.load_model(
        "data/model_training/model.h5")


    # FIXME Read threshold from file
    threshold = 0.5

    # Get a list of all predictable classes
    binarizer = get_binarizer()
    classes = [str(clazz) for clazz in binarizer.classes_]

    return (loaded_model, threshold, classes)
